@@ -26,12 +26,15 @@
 #ifndef alarm_handler_h
 #define alarm_handler_h
 
-#include <stdio.h>
+#include <cstdio>
 
 #include <string>
 
 #include "EventHandler.h"
 
+namespace libdap
+{
+
 /** Handle the time out alarm. When an OPeNDAP server runs until the time out
     alarm is triggered, this class provides the concrete implementation of
     EventHandler::handle_signal().
@@ -61,8 +64,8 @@ public:
 
     virtual ~AlarmHandler()
     {
-	if( d_file )
-	    fclose( d_file ) ;
+    	if( d_file )
+    		fclose( d_file ) ;
     }
 
     /** Handle an alarm signal. When one of our servers gets an alarm, that
@@ -103,4 +106,6 @@ public:
 
 };
 
+} // namespace libdap
+
 #endif
