@@ -37,13 +37,13 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: DODSFilter.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: DODSFilter.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
 #include <signal.h>
 
 #ifndef WIN32
-#include <unistd.h>
+#include <unistd.h>   // for getopt
 #include <sys/wait.h>
 #else
 #include <io.h>
@@ -54,6 +54,7 @@ static char rcsid[] not_used =
 #include <iostream>
 #include <string>
 #include <algorithm>
+#include <cstdlib>
 
 #include <GetOpt.h>
 
@@ -75,6 +76,8 @@ static char rcsid[] not_used =
 
 using namespace std;
 
+namespace libdap {
+
 const string usage =
     "Usage: <handler name> -o <response> -u <url> [options ...] [data set]\n\
     \n\
@@ -619,7 +622,8 @@ DODSFilter::establish_timeout(FILE *stream) const
 #ifndef WIN32
     if (d_timeout > 0) {
         SignalHandler *sh = SignalHandler::instance();
-        sh->register_handler(SIGALRM, new AlarmHandler(stream));
+        EventHandler *old_eh = sh->register_handler(SIGALRM, new AlarmHandler(stream));
+        delete old_eh;
         alarm(d_timeout);
     }
 #endif
@@ -632,7 +636,8 @@ DODSFilter::establish_timeout(ostream &stream) const
 #ifndef WIN32
     if (d_timeout > 0) {
         SignalHandler *sh = SignalHandler::instance();
-        sh->register_handler(SIGALRM, new AlarmHandler(stream));
+        EventHandler *old_eh = sh->register_handler(SIGALRM, new AlarmHandler(stream));
+        delete old_eh;
         alarm(d_timeout);
     }
 #endif
@@ -813,7 +818,7 @@ DODSFilter::send_dds(FILE *out, DDS &dds, ConstraintEvaluator &eval,
         eval.parse_constraint(d_ce, dds);
 
     if (eval.functional_expression())
-        throw Error("Function calls can only be used with data requests. To see the structure\nof the underlying data source, reissue the URL without the function.");
+        throw Error("Function calls can only be used with data requests. To see the structure of the underlying data source, reissue the URL without the function.");
 
     time_t dds_lmt = get_dds_last_modified_time(anc_location);
     if (is_conditional()
@@ -860,7 +865,7 @@ DODSFilter::send_dds(ostream &out, DDS &dds, ConstraintEvaluator &eval,
         eval.parse_constraint(d_ce, dds);
 
     if (eval.functional_expression())
-        throw Error("Function calls can only be used with data requests. To see the structure\nof the underlying data source, reissue the URL without the function.");
+        throw Error("Function calls can only be used with data requests. To see the structure of the underlying data source, reissue the URL without the function.");
 
     time_t dds_lmt = get_dds_last_modified_time(anc_location);
     if (is_conditional()
@@ -1194,6 +1199,9 @@ DODSFilter::send_ddx(DDS &dds, ConstraintEvaluator &eval, FILE *out,
     if (!d_ce.empty())
         eval.parse_constraint(d_ce, dds);
 
+    if (eval.functional_expression())
+        throw Error("Function calls can only be used with data requests. To see the structure of the underlying data source, reissue the URL without the function.");
+
     time_t dds_lmt = get_dds_last_modified_time(d_anc_dir);
 
     // If this is a conditional request and the server should send a 304
@@ -1229,6 +1237,9 @@ DODSFilter::send_ddx(DDS &dds, ConstraintEvaluator &eval, ostream &out,
     if (!d_ce.empty())
         eval.parse_constraint(d_ce, dds);
 
+    if (eval.functional_expression())
+        throw Error("Function calls can only be used with data requests. To see the structure of the underlying data source, reissue the URL without the function.");
+
     time_t dds_lmt = get_dds_last_modified_time(d_anc_dir);
 
     // If this is a conditional request and the server should send a 304
@@ -1309,3 +1320,5 @@ DODSFilter::send_blob(DDS &, FILE *, bool)
 #endif
 }
 
+} // namespace libdap
+
