@@ -32,11 +32,6 @@
 #ifndef _dodsfilter_h
 #define _dodsfilter_h
 
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include <string>
 
 #ifndef _das_h
@@ -51,6 +46,9 @@
 #include "ConstraintEvaluator.h"
 #endif
 
+namespace libdap
+{
+
 /** When a DODS server receives a request from a DODS client, the
     server CGI script dispatches the request to one of several
     ``filter'' programs.  Each filter is responsible for returning a
@@ -229,4 +227,6 @@ public:
     virtual void send_blob(DDS &dds, FILE *out, bool with_mime_headers = true);
 };
 
+} // namespace libdap
+
 #endif // _dodsfilter_h
