@@ -35,11 +35,11 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Error.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: Error.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-#include <assert.h>
+#include <cstdio>
+#include <cassert>
 
 #include "Error.h"
 #include "parser.h"
@@ -56,6 +56,8 @@ extern void *Error_buffer(FILE *fp);
 extern void Errorrestart(FILE *yyin); // defined in Error.tab.c
 extern int Errorparse(void *arg);
 
+namespace libdap {
+
 // There are two entries for 'cannot read file' because of an error made 
 // when the message was first added to this class. 
 static const char *err_messages[] = {
@@ -287,3 +289,5 @@ Error::set_error_message(string msg)
 {
     _error_message = msg;
 }
+
+} // namespace libdap
