@@ -27,15 +27,15 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 16943 2007-08-15 20:15:39Z jimg $"
+    { "$Id: HTTPConnect.cc 18650 2008-04-25 20:47:50Z jimg $"
     };
 
-#include <stdio.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 #ifdef WIN32
 #include <io.h>
-#else
-#include <unistd.h>
 #endif
 
 #include <string>
@@ -44,6 +44,8 @@ static char rcsid[] not_used =
 #include <algorithm>
 #include <sstream>
 #include <iterator>
+#include <cstdlib>
+#include <cstring>
 
 //#define DODS_DEBUG
 //#define DODS_DEBUG2
@@ -58,6 +60,8 @@ static char rcsid[] not_used =
 
 using namespace std;
 
+namespace libdap {
+
 // These global variables are not MT-Safe, but I'm leaving them as is because
 // they are used only for debugging (set them in a debugger like gdb or ddd).
 // They are not static because I *believe* that many debuggers cannot access
@@ -310,6 +314,12 @@ HTTPConnect::www_lib_init()
                          d_rcr->get_proxy_server_host().c_str());
         curl_easy_setopt(d_curl, CURLOPT_PROXYPORT,
                          d_rcr->get_proxy_server_port());
+
+	// As of 4/21/08 only NTLM, Digest and Basic work.
+#ifdef CURLOPT_PROXYAUTH
+        curl_easy_setopt(d_curl, CURLOPT_PROXYAUTH, (long)CURLAUTH_ANY);
+#endif
+
         // Password might not be required. 06/21/04 jhrg
         if (!d_rcr->get_proxy_server_userpw().empty())
             curl_easy_setopt(d_curl, CURLOPT_PROXYUSERPWD,
@@ -332,6 +342,10 @@ HTTPConnect::www_lib_init()
     // In read_url a call to CURLOPT_WRITEHEADER is used to set the fourth
     // param of save_raw_http_headers to a vector<string> object.
 
+    // Follow 302 (redirect) responses
+    curl_easy_setopt(d_curl, CURLOPT_FOLLOWLOCATION, 1);
+    curl_easy_setopt(d_curl, CURLOPT_MAXREDIRS, 5);
+
     // If the user turns off SSL validation...
     if (!d_rcr->get_validate_ssl() == 0) {
         curl_easy_setopt(d_curl, CURLOPT_SSL_VERIFYPEER, 0);
@@ -602,6 +616,69 @@ HTTPConnect::fetch_url(const string &url)
     return stream;
 }
 
+// Look around for a reasonable place to put a temporary file. Check first
+// the value of the TMPDIR env var. If that does not yeild a path that's
+// writable (as defined by access(..., W_OK|R_OK)) then look at P_tmpdir (as
+// defined in stdio.h. If both come up empty, then use `./'.
+//
+// This function allocates storage using new. The caller must delete the char
+// array.
+
+// Change this to a version that either returns a string or an open file
+// descriptor. Use information from https://buildsecurityin.us-cert.gov/
+// (see open()) to make it more secure. Ideal solution: get deserialize()
+// methods to read from a stream returned by libcurl, not from a temporary
+// file. 9/21/07 jhrg
+static char *
+get_tempfile_template(char *file_template)
+{
+    char *c;
+    
+#ifdef WIN32
+    // whitelist for a WIN32 directory
+    Regex directory("[-a-zA-Z0-9_\\]*");
+	
+    c = getenv("TEMP");
+    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0))
+    	goto valid_temp_directory;
+
+    c= getenv("TMP");
+    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0))
+    	goto valid_temp_directory;
+#else
+	// whitelist for a directory
+	Regex directory("[-a-zA-Z0-9_/]*");
+	
+	c = getenv("TMPDIR");
+	if (c && directory.match(c, strlen(c)) && (access(c, W_OK | R_OK) == 0))
+    	goto valid_temp_directory;
+
+#ifdef P_tmpdir
+	if (access(P_tmpdir, W_OK | R_OK) == 0) {
+        c = P_tmpdir;
+        goto valid_temp_directory;
+	}
+#endif
+
+#endif  // WIN32
+
+    c = ".";
+    
+valid_temp_directory:
+	// Sanitize allocation
+	int size = strlen(c) + strlen(file_template) + 2;
+	if (!size_ok(1, size))
+		throw Error("Bad temporary file name.");
+		
+    char *temp = new char[size];
+    strncpy(temp, c, size-2);
+    strcat(temp, "/");
+
+    strcat(temp, file_template);
+
+    return temp;
+}
+
 /** Open a temporary file and return its name. This method opens a temporary
     file using get_tempfile_template(). The FILE* \c stream is opened for
     both reads and writes; if it already exists (highly unlikely), it is
@@ -697,7 +774,7 @@ HTTPConnect::caching_fetch_url(const string &url)
             // *** auto_ptr??? resp_hdrs not deleted! 10/10/03 jhrg
             vector<string> *resp_hdrs = new vector<string>;
             vector<string> cond_hdrs
-            = d_http_cache->get_conditional_request_headers(url);
+		= d_http_cache->get_conditional_request_headers(url);
             FILE *body = 0;
             string dods_temp = get_temp_file(body);
             time_t now = time(0); // When was the request made (now).
@@ -869,3 +946,5 @@ HTTPConnect::set_credentials(const string &u, const string &p)
 
     d_upstring = u + ":" + p;
 }
+
+} // namespace libdap
