@@ -26,8 +26,7 @@
 #ifndef http_response_h
 #define http_response_h
 
-#include <stdio.h>
-
+#include <cstdio>
 #include <string>
 #include <iostream>
 #include <algorithm>
@@ -41,6 +40,9 @@
 #include "debug.h"
 #endif
 
+namespace libdap
+{
+
 extern int dods_keep_temps; // defined in HTTPConnect.cc
 extern void close_temp(FILE *s, const string &name);
 
@@ -128,4 +130,6 @@ public:
     //@}
 };
 
+} // namespace libdap
+
 #endif // http_response_h
