@@ -36,8 +36,6 @@
 
 #include "config.h"
 
-#include <stdlib.h>
-
 #include "Structure.h"
 #include "util.h"
 #include "debug.h"
@@ -47,6 +45,8 @@
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 void
 Structure::_duplicate(const Structure &s)
 {
@@ -489,3 +489,5 @@ Structure::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
