@@ -105,13 +105,10 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: ce_expr.y 16519 2007-05-17 23:15:40Z jimg $"};
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+static char rcsid[] not_used = {"$Id: ce_expr.y 18315 2008-03-03 20:14:44Z jimg $"};
 
+#include <cassert>
+#include <cstdlib>
 #include <string>
 
 #include "debug.h"
@@ -135,6 +132,7 @@ static char rcsid[] not_used = {"$Id: ce_expr.y 16519 2007-05-17 23:15:40Z jimg
 
 using std::cerr;
 using std::endl;
+using namespace libdap ;
 
 #define EVALUATOR(arg) (static_cast<ce_parser_arg*>(arg)->get_eval())
 #define DDS(arg) (static_cast<ce_parser_arg*>(arg)->get_dds())
@@ -206,25 +204,25 @@ proj_func get_proj_function(const ConstraintEvaluator &eval, const char *name);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 126 "ce_expr.y"
+#line 124 "ce_expr.y"
 {
     bool boolean;
     int op;
     char id[ID_MAX];
 
-    value val;
+    libdap::value val;
 
-    bool_func b_func;
-    btp_func bt_func;
+    libdap::bool_func b_func;
+    libdap::btp_func bt_func;
 
-    int_list *int_l_ptr;
-    int_list_list *int_ll_ptr;
+    libdap::int_list *int_l_ptr;
+    libdap::int_list_list *int_ll_ptr;
     
-    rvalue *rval_ptr;
-    rvalue_list *r_val_l_ptr;
+    libdap::rvalue *rval_ptr;
+    libdap::rvalue_list *r_val_l_ptr;
 }
-/* Line 193 of yacc.c.  */
-#line 228 "ce_expr.tab.c"
+/* Line 187 of yacc.c.  */
+#line 226 "ce_expr.tab.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -237,7 +235,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 241 "ce_expr.tab.c"
+#line 239 "ce_expr.tab.cc"
 
 #ifdef short
 # undef short
@@ -533,10 +531,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   166,   166,   171,   173,   173,   177,   183,   184,   190,
-     202,   206,   212,   233,   234,   240,   249,   260,   266,   279,
-     290,   302,   309,   318,   323,   328,   359,   366,   376,   380,
-     386,   398,   416,   442,   443,   444,   445,   446,   447,   448
+       0,   164,   164,   169,   171,   171,   175,   181,   182,   188,
+     200,   204,   210,   232,   233,   239,   248,   259,   265,   278,
+     289,   301,   308,   317,   322,   327,   358,   365,   375,   379,
+     385,   397,   415,   441,   442,   443,   444,   445,   446,   447
 };
 #endif
 
@@ -1476,7 +1474,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 166 "ce_expr.y"
+#line 164 "ce_expr.y"
     {
 		     DDS(arg)->mark_all(true);
 		     (yyval.boolean) = true;
@@ -1484,33 +1482,33 @@ yyreduce:
     break;
 
   case 4:
-#line 173 "ce_expr.y"
+#line 171 "ce_expr.y"
     { DDS(arg)->mark_all(true); ;}
     break;
 
   case 5:
-#line 174 "ce_expr.y"
+#line 172 "ce_expr.y"
     { 
 		     (yyval.boolean) = (yyvsp[(3) - (3)].boolean);
 		 ;}
     break;
 
   case 6:
-#line 178 "ce_expr.y"
+#line 176 "ce_expr.y"
     {
 		     (yyval.boolean) = (yyvsp[(1) - (3)].boolean) && (yyvsp[(3) - (3)].boolean);
 		 ;}
     break;
 
   case 8:
-#line 185 "ce_expr.y"
+#line 183 "ce_expr.y"
     {
 		    (yyval.boolean) = (yyvsp[(1) - (3)].boolean) && (yyvsp[(3) - (3)].boolean);
 		;}
     break;
 
   case 9:
-#line 191 "ce_expr.y"
+#line 189 "ce_expr.y"
     { 
 		    BaseType *var = DDS(arg)->var((yyvsp[(1) - (1)].id));
 		    if (var) {
@@ -1525,21 +1523,21 @@ yyreduce:
     break;
 
   case 10:
-#line 203 "ce_expr.y"
+#line 201 "ce_expr.y"
     {
 		    (yyval.boolean) = (yyvsp[(1) - (1)].boolean);
 		;}
     break;
 
   case 11:
-#line 207 "ce_expr.y"
+#line 205 "ce_expr.y"
     {
 		    (yyval.boolean) = (yyvsp[(1) - (1)].boolean);
 		;}
     break;
 
   case 12:
-#line 213 "ce_expr.y"
+#line 211 "ce_expr.y"
     {
 		    proj_func p_f = 0;
 		    btp_func f = 0;
@@ -1552,6 +1550,7 @@ yyreduce:
 		        DDS &dds = dynamic_cast<DDS&>(*(DDS(arg)));
 			BaseType **args = build_btp_args( (yyvsp[(3) - (4)].r_val_l_ptr), dds, dds.get_dataset_name() );
 			(*p_f)(((yyvsp[(3) - (4)].r_val_l_ptr)) ? (yyvsp[(3) - (4)].r_val_l_ptr)->size():0, args, dds, *(EVALUATOR(arg)));
+			delete[] args;
 			(yyval.boolean) = true;
 		    }
 		    else {
@@ -1561,14 +1560,14 @@ yyreduce:
     break;
 
   case 14:
-#line 235 "ce_expr.y"
+#line 234 "ce_expr.y"
     {
 		    (yyval.boolean) = (yyvsp[(1) - (3)].boolean) && (yyvsp[(3) - (3)].boolean);
 		;}
     break;
 
   case 15:
-#line 241 "ce_expr.y"
+#line 240 "ce_expr.y"
     {
 		    if ((yyvsp[(1) - (5)].rval_ptr)) {
 			EVALUATOR(arg)->append_clause((yyvsp[(2) - (5)].op), (yyvsp[(1) - (5)].rval_ptr), (yyvsp[(4) - (5)].r_val_l_ptr));
@@ -1580,7 +1579,7 @@ yyreduce:
     break;
 
   case 16:
-#line 250 "ce_expr.y"
+#line 249 "ce_expr.y"
     {
 		    if ((yyvsp[(1) - (3)].rval_ptr)) {
 			rvalue_list *rv = new rvalue_list;
@@ -1594,14 +1593,14 @@ yyreduce:
     break;
 
   case 17:
-#line 261 "ce_expr.y"
+#line 260 "ce_expr.y"
     {
 		    (yyval.boolean) = (yyvsp[(1) - (1)].boolean);
 		;}
     break;
 
   case 18:
-#line 267 "ce_expr.y"
+#line 266 "ce_expr.y"
     {
 		   bool_func b_func = get_function((*EVALUATOR(arg)), (yyvsp[(1) - (4)].id));
 		   if (!b_func) {
@@ -1615,7 +1614,7 @@ yyreduce:
     break;
 
   case 20:
-#line 291 "ce_expr.y"
+#line 290 "ce_expr.y"
     {
 		    btp_func func = get_btp_function((*EVALUATOR(arg)), (yyvsp[(1) - (4)].id));
 		    if (func) {
@@ -1628,7 +1627,7 @@ yyreduce:
     break;
 
   case 21:
-#line 303 "ce_expr.y"
+#line 302 "ce_expr.y"
     {
 		    if ((yyvsp[(1) - (1)].rval_ptr))
 			(yyval.r_val_l_ptr) = make_rvalue_list((yyvsp[(1) - (1)].rval_ptr));
@@ -1638,7 +1637,7 @@ yyreduce:
     break;
 
   case 22:
-#line 310 "ce_expr.y"
+#line 309 "ce_expr.y"
     {
 		    if ((yyvsp[(1) - (3)].r_val_l_ptr) && (yyvsp[(3) - (3)].rval_ptr))
 			(yyval.r_val_l_ptr) = append_rvalue_list((yyvsp[(1) - (3)].r_val_l_ptr), (yyvsp[(3) - (3)].rval_ptr));
@@ -1648,21 +1647,21 @@ yyreduce:
     break;
 
   case 23:
-#line 319 "ce_expr.y"
+#line 318 "ce_expr.y"
     {  
 		  (yyval.r_val_l_ptr) = (yyvsp[(1) - (1)].r_val_l_ptr);
 	      ;}
     break;
 
   case 24:
-#line 323 "ce_expr.y"
+#line 322 "ce_expr.y"
     { 
 		  (yyval.r_val_l_ptr) = 0; 
 	      ;}
     break;
 
   case 25:
-#line 329 "ce_expr.y"
+#line 328 "ce_expr.y"
     { 
 		    BaseType *btp = DDS(arg)->var(www2id(string((yyvsp[(1) - (1)].id))));
 		    if (!btp) {
@@ -1696,7 +1695,7 @@ yyreduce:
     break;
 
   case 26:
-#line 360 "ce_expr.y"
+#line 359 "ce_expr.y"
     { 
 		    BaseType *btp = make_variable((*DDS(arg)), (*EVALUATOR(arg)), (yyvsp[(1) - (1)].val)); 
 		    (yyval.rval_ptr) = new rvalue(btp);
@@ -1704,7 +1703,7 @@ yyreduce:
     break;
 
   case 27:
-#line 367 "ce_expr.y"
+#line 366 "ce_expr.y"
     {
 		  if (!bracket_projection((*DDS(arg)), (yyvsp[(1) - (2)].id), (yyvsp[(2) - (2)].int_ll_ptr)))
 		    // no_such_ident throws an exception.
@@ -1715,21 +1714,21 @@ yyreduce:
     break;
 
   case 28:
-#line 377 "ce_expr.y"
+#line 376 "ce_expr.y"
     {
 		    (yyval.int_ll_ptr) = make_array_indices((yyvsp[(1) - (1)].int_l_ptr));
 		;}
     break;
 
   case 29:
-#line 381 "ce_expr.y"
+#line 380 "ce_expr.y"
     {
 		    (yyval.int_ll_ptr) = append_array_index((yyvsp[(1) - (2)].int_ll_ptr), (yyvsp[(2) - (2)].int_l_ptr));
 		;}
     break;
 
   case 30:
-#line 387 "ce_expr.y"
+#line 386 "ce_expr.y"
     {
 		    if (!check_uint32((yyvsp[(2) - (3)].id))) {
 			string msg = "The word `";
@@ -1744,7 +1743,7 @@ yyreduce:
     break;
 
   case 31:
-#line 399 "ce_expr.y"
+#line 398 "ce_expr.y"
     {
 		    if (!check_uint32((yyvsp[(2) - (5)].id))) {
 			string msg = "The word `";
@@ -1765,7 +1764,7 @@ yyreduce:
     break;
 
   case 32:
-#line 417 "ce_expr.y"
+#line 416 "ce_expr.y"
     {
 		    if (!check_uint32((yyvsp[(2) - (7)].id))) {
 			string msg = "The word `";
@@ -1793,7 +1792,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1797 "ce_expr.tab.c"
+#line 1796 "ce_expr.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2007,7 +2006,7 @@ yyreturn:
 }
 
 
-#line 451 "ce_expr.y"
+#line 450 "ce_expr.y"
 
 
 // All these error reporting function now throw instances of Error. The expr
@@ -2167,13 +2166,13 @@ bracket_projection(DDS &table, const char *name, int_list_list *indices)
 int_list *
 make_array_index(value &i1, value &i2, value &i3)
 {
-    int_list *index = new int_list;
-
     if (i1.type != dods_uint32_c
 	|| i2.type != dods_uint32_c
 	|| i3.type != dods_uint32_c)
 	return (int_list *)0;
 
+    int_list *index = new int_list;
+
     index->push_back((int)i1.v.i);
     index->push_back((int)i2.v.i);
     index->push_back((int)i3.v.i);
@@ -2189,11 +2188,11 @@ make_array_index(value &i1, value &i2, value &i3)
 int_list *
 make_array_index(value &i1, value &i2)
 {
-    int_list *index = new int_list;
-
     if (i1.type != dods_uint32_c || i2.type != dods_uint32_c)
 	return (int_list *)0;
 
+    int_list *index = new int_list;
+ 
     index->push_back((int)i1.v.i);
     index->push_back(1);
     index->push_back((int)i2.v.i);
@@ -2209,11 +2208,11 @@ make_array_index(value &i1, value &i2)
 int_list *
 make_array_index(value &i1)
 {
-    int_list *index = new int_list;
-
     if (i1.type != dods_uint32_c)
 	return (int_list *)0;
 
+    int_list *index = new int_list;
+
     index->push_back((int)i1.v.i);
     index->push_back(1);
     index->push_back((int)i1.v.i);
@@ -2691,3 +2690,4 @@ get_proj_function(const ConstraintEvaluator &eval, const char *name)
 	return 0;
 }
 
+
