@@ -36,13 +36,14 @@
 #include "config.h"
 
 static char rcsid[]not_used =
-{   "$Id: ce_functions.cc 17299 2007-10-24 19:39:50Z jimg $"
+{   "$Id: ce_functions.cc 18315 2008-03-03 20:14:44Z jimg $"
 };
 
-#include <errno.h>      // used by strtod()
 #include <limits.h>
-#include <math.h>
 
+#include <cstdlib>      // used by strtod()
+#include <cerrno>
+#include <cmath>
 #include <iostream>
 #include <vector>
 #include <algorithm>
@@ -62,7 +63,7 @@ static char rcsid[]not_used =
 
 #include "ce_functions.h"
 #include "gse_parser.h"
-#include "gse.tab.h"
+#include "gse.tab.hh"
 #include "debug.h"
 #include "util.h"
 
@@ -340,7 +341,7 @@ static void apply_grid_selection_expr(Grid * grid, GSEClause * clause)
         ++map_i;
 
     if (map_i == grid->map_end())
-        throw Error("The map vector '" + clause->get_map_name()
+        throw Error(malformed_expr,"The map vector '" + clause->get_map_name()
                 + "' is not in the grid '" + grid->name() + "'.");
 
     // Use pointer arith & the rule that map order must match array dim order
@@ -358,7 +359,7 @@ static void apply_grid_selection_expr(Grid * grid, GSEClause * clause)
                 << "'. The map's values range " << "from "
                 << clause->get_map_min_value() << " to "
                 << clause->get_map_max_value() << ".";
-        throw Error(msg.str());
+        throw Error(malformed_expr,msg.str());
     }
 
     DBG(cerr << "Setting constraint on " << map->name()
@@ -442,7 +443,7 @@ BaseType *function_grid(int argc, BaseType * argv[], DDS &,
 
     Grid *original_grid = dynamic_cast < Grid * >(argv[0]);
     if (!original_grid)
-        throw Error("The first argument to grid() must be a Grid variable!");
+        throw Error(malformed_expr,"The first argument to grid() must be a Grid variable!");
 
     // Duplicate the grid; DODSFilter::send_data() will delete the variable
     // after serializing it.
@@ -548,11 +549,11 @@ BaseType *function_geogrid(int argc, BaseType * argv[], DDS &,
     }
 
     if (argc < 5)
-        throw Error("Wrong number of arguments to geogrid(). See geogrid() for more information.");
+        throw Error(malformed_expr,"Wrong number of arguments to geogrid(). See geogrid() for more information.");
 
     Grid *l_grid = dynamic_cast < Grid * >(argv[0]->ptr_duplicate());
     if (!l_grid)
-        throw Error("The first argument to geogrid() must be a Grid variable!");
+        throw Error(malformed_expr,"The first argument to geogrid() must be a Grid variable!");
 
     // Read the maps. Do this before calling parse_gse_expression(). Avoid
     // reading the array until the constraints have been applied because it
@@ -642,24 +643,16 @@ static double string_to_double(const char *val)
 
     if ((v == 0.0 && (val == ptr || errno == HUGE_VAL || errno == ERANGE))
             || *ptr != '\0') {
-        throw Error(string("Could not convert the string '") + val + "' to a double.");
+        throw Error(malformed_expr,string("Could not convert the string '") + val + "' to a double.");
     }
 
     double abs_val = fabs(v);
     if (abs_val > DODS_DBL_MAX || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
-        throw Error(string("Could not convert the string '") + val + "' to a double.");
+        throw Error(malformed_expr,string("Could not convert the string '") + val + "' to a double.");
 
     return v;
 }
 
-static string remove_quotes(const string &s)
-{
-    if (s[0] == '\"' && s[s.length()-1] == '\"')
-        return s.substr(1, s.length() - 2);
-    else
-        return s;
-}
-
 /** Look for any one of a series of attribute values in the attribute table
  for \e var.
  @return The attribute value in a double. */
@@ -683,7 +676,7 @@ static double get_attribute_double_value(BaseType *var,
         if (var->type() == dods_grid_c)
             return get_attribute_double_value(dynamic_cast<Grid&>(*var).get_array(), attributes);
         else
-            throw Error(string("No COARDS '") + values.substr(0, values.length() - 2)
+            throw Error(malformed_expr,string("No COARDS '") + values.substr(0, values.length() - 2)
                     + "' attribute was found for the variable '"
                     + var->name() + "'.");
     }
@@ -702,7 +695,7 @@ static double get_attribute_double_value(BaseType *var, const string &attribute)
         if (var->type() == dods_grid_c)
             return get_attribute_double_value(dynamic_cast<Grid&>(*var).get_array(), attribute);
         else
-            throw Error(string("No COARDS '") + attribute
+            throw Error(malformed_expr,string("No COARDS '") + attribute
                     + "' attribute was found for the variable '"
                     + var->name() + "'.");
     }
@@ -769,7 +762,7 @@ BaseType * function_linear_scale(int argc, BaseType * argv[], DDS &,
     // Check for 1 or 3 arguments: 1 --> use attributes; 3 --> m & b supplied
     DBG(cerr << "argc = " << argc << endl);
     if (!(argc == 1 || argc == 3 || argc == 4))
-        throw Error("Wrong number of arguments to linear_scale(). See linear_scale() for more information");
+        throw Error(malformed_expr,"Wrong number of arguments to linear_scale(). See linear_scale() for more information");
 
     // Get m & b
     bool use_missing = false;
@@ -833,6 +826,7 @@ BaseType * function_linear_scale(int argc, BaseType * argv[], DDS &,
         Float64 *temp_f = new Float64(source.name());
         source.add_var(temp_f);
         source.val2buf(static_cast<void*>(data), false);
+        delete [] data; // val2buf copies.
         delete temp_f; // add_var copies and then adds.
         dest = argv[0];
     } else if (argv[0]->is_vector_type()) {
@@ -857,6 +851,7 @@ BaseType * function_linear_scale(int argc, BaseType * argv[], DDS &,
         Float64 *temp_f = new Float64(source.name());
         source.add_var(temp_f);
         source.val2buf(static_cast<void*>(data), false);
+        delete [] data; // val2buf copies.
         delete temp_f; // add_var copies and then adds.
 
         dest = argv[0];
@@ -869,7 +864,7 @@ BaseType * function_linear_scale(int argc, BaseType * argv[], DDS &,
         dest = new Float64(argv[0]->name());
         dest->val2buf(static_cast<void*>(&data));
     } else {
-        throw Error("The linear_scale() function works only for numeric Grids, Arrays and scalars.");
+        throw Error(malformed_expr,"The linear_scale() function works only for numeric Grids, Arrays and scalars.");
     }
 
     return dest;
@@ -916,12 +911,12 @@ BaseType * function_geoarray(int argc, BaseType * argv[], DDS &,
 
     DBG(cerr << "argc = " << argc << endl);
     if (!(argc == 5 || argc == 9 || argc == 11))
-        throw Error("Wrong number of arguments to geoarray(). See geoarray() for more information.");
+        throw Error(malformed_expr,"Wrong number of arguments to geoarray(). See geoarray() for more information.");
 
     // Check the Array (and dup because the caller will free the variable).
     Array *l_array = dynamic_cast < Array * >(argv[0]->ptr_duplicate());
     if (!l_array)
-        throw Error("The first argument to geoarray() must be an Array variable!");
+        throw Error(malformed_expr,"The first argument to geoarray() must be an Array variable!");
 
     try {
 
@@ -931,18 +926,28 @@ BaseType * function_geoarray(int argc, BaseType * argv[], DDS &,
         double bb_bottom = extract_double_value(argv[3]);
         double bb_right = extract_double_value(argv[4]);
 
-        ArrayGeoConstraint *agc = 0;
         switch (argc) {
-            case 5:
-            agc = new ArrayGeoConstraint(l_array, dataset);
-            break;
+            case 5: {
+            	ArrayGeoConstraint agc(l_array, dataset);
+         		
+         		agc.set_bounding_box(bb_left, bb_top, bb_right, bb_bottom);
+				// This also reads all of the data into the grid variable
+        		agc.apply_constraint_to_data();
+        		return agc.get_constrained_array();
+            	break;
+            }
             case 9: {
                 double var_top = extract_double_value(argv[5]);
                 double var_left = extract_double_value(argv[6]);
                 double var_bottom = extract_double_value(argv[7]);
                 double var_right = extract_double_value(argv[8]);
-                agc = new ArrayGeoConstraint(l_array, dataset,
+                ArrayGeoConstraint agc (l_array, dataset,
                         var_left, var_top, var_right, var_bottom);
+                        
+        		agc.set_bounding_box(bb_left, bb_top, bb_right, bb_bottom);
+				// This also reads all of the data into the grid variable
+        		agc.apply_constraint_to_data();
+        		return agc.get_constrained_array();
                 break;
             }
             case 11: {
@@ -952,23 +957,19 @@ BaseType * function_geoarray(int argc, BaseType * argv[], DDS &,
                 double var_right = extract_double_value(argv[8]);
                 string projection = extract_string_argument(argv[9]);
                 string datum = extract_string_argument(argv[10]);
-                agc = new ArrayGeoConstraint(l_array, dataset,
+                ArrayGeoConstraint agc(l_array, dataset,
                         var_left, var_top, var_right, var_bottom,
                         projection, datum);
+        
+        		agc.set_bounding_box(bb_left, bb_top, bb_right, bb_bottom);
+				// This also reads all of the data into the grid variable
+        		agc.apply_constraint_to_data();
+        		return agc.get_constrained_array();
                 break;
             }
             default:
-            throw InternalErr(__FILE__, __LINE__, "Wrong number of args to geoarray.");
+            	throw InternalErr(__FILE__, __LINE__, "Wrong number of args to geoarray.");
         }
-
-        agc->set_bounding_box(bb_left, bb_top, bb_right, bb_bottom);
-
-        // This also reads all of the data into the grid variable
-        agc->apply_constraint_to_data();
-
-        // In this function the l_grid pointer is the same as the pointer returned
-        // by this call. The caller of the function must free the pointer.
-        return agc->get_constrained_array();
     }
     catch (Error & e) {
         throw e;
@@ -980,6 +981,8 @@ BaseType * function_geoarray(int argc, BaseType * argv[], DDS &,
                 + e.what());
 
     }
+    
+    throw InternalErr(__FILE__, __LINE__, "Impossible condition in geoarray.");
 }
 
 void register_functions(ConstraintEvaluator & ce)
