@@ -38,11 +38,11 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: cgi_util.cc 17156 2007-09-21 17:44:27Z jimg $"
+    {"$Id: cgi_util.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdio>
 #include <ctype.h>
 
 #ifndef TM_IN_SYS_TIME
@@ -55,7 +55,7 @@ static char rcsid[] not_used =
 #include <sys/stat.h>
 
 #ifndef WIN32
-#include <unistd.h>
+#include <unistd.h>    // for access
 #include <sys/wait.h>
 #else
 #include <io.h>
@@ -86,6 +86,8 @@ static char rcsid[] not_used =
 
 using namespace std;
 
+namespace libdap {
+
 static const int TimLen = 26; // length of string from asctime()
 static const int CLUMP_SIZE = 1024; // size of clumps to new in fmakeword()
 
@@ -410,6 +412,9 @@ static const char *months[] =
      "Aug", "Sep", "Oct", "Nov", "Dec"
     };
 
+#ifdef _MSC_VER
+#define snprintf sprintf_s
+#endif
 /** Given a constant pointer to a <tt>time_t</tt>, return a RFC
     822/1123 style date.
 
@@ -863,6 +868,7 @@ found_override(string name, string &doc)
         doc += tmp;
     }
 
+	ifs.close();
     return true;
 }
 
@@ -952,3 +958,5 @@ get_user_supplied_docs(string name, string cgi)
     return oss.str();
 }
 
+} // namespace libdap
+
