@@ -119,12 +119,10 @@
 
 #include "config_dap.h"
 
-static char rcsid[] not_used = {"$Id: dds.y 16936 2007-08-13 20:01:09Z jimg $"};
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
+static char rcsid[] not_used = {"$Id: dds.y 18315 2008-03-03 20:14:44Z jimg $"};
 
+#include <cstring>
+#include <cassert>
 #include <iostream>
 #include <stack>
 #include <sstream>
@@ -135,7 +133,8 @@ static char rcsid[] not_used = {"$Id: dds.y 16936 2007-08-13 20:01:09Z jimg $"};
 #include "parser.h"
 #include "util.h"
 
- using namespace std;
+using namespace std;
+using namespace libdap;
 
 // These macros are used to access the `arguments' passed to the parser. A
 // pointer to an error object and a pointer to an integer status variable are
@@ -195,13 +194,13 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 109 "dds.y"
+#line 108 "dds.y"
 {
     bool boolean;
     char word[ID_MAX];
 }
-/* Line 193 of yacc.c.  */
-#line 205 "dds.tab.c"
+/* Line 187 of yacc.c.  */
+#line 204 "dds.tab.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -214,7 +213,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 218 "dds.tab.c"
+#line 217 "dds.tab.cc"
 
 #ifdef short
 # undef short
@@ -516,12 +515,12 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   138,   138,   138,   148,   149,   152,   156,   166,   170,
-     171,   178,   201,   200,   221,   220,   241,   253,   265,   240,
-     286,   297,   303,   309,   315,   316,   317,   318,   319,   320,
-     321,   322,   323,   326,   327,   330,   330,   330,   330,   330,
-     331,   331,   331,   331,   332,   332,   332,   332,   333,   336,
-     358,   362,   357,   386,   397,   398,   399
+       0,   137,   137,   137,   147,   148,   151,   155,   165,   169,
+     170,   177,   200,   199,   220,   219,   240,   252,   264,   239,
+     285,   296,   302,   308,   314,   315,   316,   317,   318,   319,
+     320,   321,   322,   325,   326,   329,   329,   329,   329,   329,
+     330,   330,   330,   330,   331,   331,   331,   331,   332,   335,
+     357,   361,   356,   385,   396,   397,   398
 };
 #endif
 
@@ -1502,7 +1501,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 138 "dds.y"
+#line 137 "dds.y"
     {
 		    /* On entry to the parser, make the BaseType stack. */
 		    ctor = new stack<BaseType *>;
@@ -1510,21 +1509,21 @@ yyreduce:
     break;
 
   case 3:
-#line 143 "dds.y"
+#line 142 "dds.y"
     {
 		    delete ctor; ctor = 0;
 		;}
     break;
 
   case 6:
-#line 153 "dds.y"
+#line 152 "dds.y"
     {
 		    (yyval.boolean) = (yyvsp[(3) - (6)].boolean) && (yyvsp[(5) - (6)].word);
 		;}
     break;
 
   case 7:
-#line 157 "dds.y"
+#line 156 "dds.y"
     {
 		    parse_error((parser_arg *)arg, NO_DDS_MSG,
  				dds_line_num, (yyvsp[(1) - (1)].word));
@@ -1534,24 +1533,24 @@ yyreduce:
     break;
 
   case 8:
-#line 166 "dds.y"
+#line 165 "dds.y"
     {
 		    (yyval.boolean) = true;
 		;}
     break;
 
   case 9:
-#line 170 "dds.y"
+#line 169 "dds.y"
     { (yyval.boolean) = true; ;}
     break;
 
   case 10:
-#line 171 "dds.y"
+#line 170 "dds.y"
     { (yyval.boolean) = true; ;}
     break;
 
   case 11:
-#line 179 "dds.y"
+#line 178 "dds.y"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1575,7 +1574,7 @@ yyreduce:
     break;
 
   case 12:
-#line 201 "dds.y"
+#line 200 "dds.y"
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1584,7 +1583,7 @@ yyreduce:
     break;
 
   case 13:
-#line 207 "dds.y"
+#line 206 "dds.y"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg))
@@ -1600,7 +1599,7 @@ yyreduce:
     break;
 
   case 14:
-#line 221 "dds.y"
+#line 220 "dds.y"
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1609,7 +1608,7 @@ yyreduce:
     break;
 
   case 15:
-#line 227 "dds.y"
+#line 226 "dds.y"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg))
@@ -1625,7 +1624,7 @@ yyreduce:
     break;
 
   case 16:
-#line 241 "dds.y"
+#line 240 "dds.y"
     { 
 		    if (is_keyword(string((yyvsp[(3) - (4)].word)), "array"))
 			part = array; 
@@ -1640,7 +1639,7 @@ yyreduce:
     break;
 
   case 17:
-#line 253 "dds.y"
+#line 252 "dds.y"
     { 
 		    if (is_keyword(string((yyvsp[(7) - (8)].word)), "maps"))
 			part = maps; 
@@ -1655,7 +1654,7 @@ yyreduce:
     break;
 
   case 18:
-#line 265 "dds.y"
+#line 264 "dds.y"
     {
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1664,7 +1663,7 @@ yyreduce:
     break;
 
   case 19:
-#line 271 "dds.y"
+#line 270 "dds.y"
     {
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1682,7 +1681,7 @@ yyreduce:
     break;
 
   case 20:
-#line 287 "dds.y"
+#line 286 "dds.y"
     {
 		    ostringstream msg;
 		    msg << BAD_DECLARATION;
@@ -1693,78 +1692,78 @@ yyreduce:
     break;
 
   case 21:
-#line 298 "dds.y"
+#line 297 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		;}
     break;
 
   case 22:
-#line 304 "dds.y"
+#line 303 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		;}
     break;
 
   case 23:
-#line 310 "dds.y"
+#line 309 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		;}
     break;
 
   case 24:
-#line 315 "dds.y"
+#line 314 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); ;}
     break;
 
   case 25:
-#line 316 "dds.y"
+#line 315 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); ;}
     break;
 
   case 26:
-#line 317 "dds.y"
+#line 316 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); ;}
     break;
 
   case 27:
-#line 318 "dds.y"
+#line 317 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); ;}
     break;
 
   case 28:
-#line 319 "dds.y"
+#line 318 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); ;}
     break;
 
   case 29:
-#line 320 "dds.y"
+#line 319 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); ;}
     break;
 
   case 30:
-#line 321 "dds.y"
+#line 320 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); ;}
     break;
 
   case 31:
-#line 322 "dds.y"
+#line 321 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); ;}
     break;
 
   case 32:
-#line 323 "dds.y"
+#line 322 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); ;}
     break;
 
   case 33:
-#line 326 "dds.y"
+#line 325 "dds.y"
     { current->set_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 49:
-#line 337 "dds.y"
+#line 336 "dds.y"
     { 
 		     if (!check_int32((yyvsp[(2) - (3)].word))) {
 			 string msg = "In the dataset descriptor object:\n";
@@ -1787,14 +1786,14 @@ yyreduce:
     break;
 
   case 50:
-#line 358 "dds.y"
+#line 357 "dds.y"
     {
 		     id = new string((yyvsp[(2) - (2)].word));
 		 ;}
     break;
 
   case 51:
-#line 362 "dds.y"
+#line 361 "dds.y"
     { 
 		     if (!check_int32((yyvsp[(5) - (5)].word))) {
 			 string msg = "In the dataset descriptor object:\n";
@@ -1820,7 +1819,7 @@ yyreduce:
     break;
 
   case 53:
-#line 387 "dds.y"
+#line 386 "dds.y"
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
@@ -1832,17 +1831,17 @@ yyreduce:
     break;
 
   case 54:
-#line 397 "dds.y"
+#line 396 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 55:
-#line 398 "dds.y"
+#line 397 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 56:
-#line 400 "dds.y"
+#line 399 "dds.y"
     {
 		  ostringstream msg;
 		  msg << "Error parsing the dataset name." << endl
@@ -1855,7 +1854,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1859 "dds.tab.c"
+#line 1858 "dds.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2069,7 +2068,7 @@ yyreturn:
 }
 
 
-#line 410 "dds.y"
+#line 409 "dds.y"
 
 
 /* 
