@@ -107,7 +107,7 @@
 
 #include "config_dap.h"
 
-static char rcsid[] not_used = {"$Id: gse.y 16519 2007-05-17 23:15:40Z jimg $"};
+static char rcsid[] not_used = {"$Id: gse.y 17856 2008-02-02 21:25:59Z pwest $"};
 
 #include <iostream>
 
@@ -117,6 +117,7 @@ static char rcsid[] not_used = {"$Id: gse.y 16519 2007-05-17 23:15:40Z jimg $"};
 
 using std::cerr;
 using std::endl;
+using namespace libdap;
 
 // This macro is used to access the instance of a gse_arg class which is
 // passed to the parser through a void *. See parser.h.
@@ -157,7 +158,7 @@ build_dual_gse_clause(gse_arg *arg, char id[ID_MAX], int op1, double val1,
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 69 "gse.y"
+#line 70 "gse.y"
 {
     bool boolean;
 
@@ -165,8 +166,8 @@ typedef union YYSTYPE
     char id[ID_MAX];
     double val;
 }
-/* Line 193 of yacc.c.  */
-#line 170 "gse.tab.c"
+/* Line 187 of yacc.c.  */
+#line 171 "gse.tab.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -179,7 +180,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 183 "gse.tab.c"
+#line 184 "gse.tab.cc"
 
 #ifdef short
 # undef short
@@ -465,8 +466,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    97,    97,   103,   109,   118,   121,   122,   125,   126,
-     127,   128,   129,   130
+       0,    98,    98,   104,   110,   119,   122,   123,   126,   127,
+     128,   129,   130,   131
 };
 #endif
 
@@ -1373,7 +1374,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 98 "gse.y"
+#line 99 "gse.y"
     {
 		    ((gse_arg *)arg)->set_gsec(
 			build_gse_clause((gse_arg *)(arg), (yyvsp[(1) - (3)].id), (yyvsp[(2) - (3)].op), (yyvsp[(3) - (3)].val)));
@@ -1382,7 +1383,7 @@ yyreduce:
     break;
 
   case 3:
-#line 104 "gse.y"
+#line 105 "gse.y"
     {
 		    ((gse_arg *)arg)->set_gsec(
 		       build_rev_gse_clause((gse_arg *)(arg), (yyvsp[(3) - (3)].id), (yyvsp[(2) - (3)].op), (yyvsp[(1) - (3)].val)));
@@ -1391,7 +1392,7 @@ yyreduce:
     break;
 
   case 4:
-#line 110 "gse.y"
+#line 111 "gse.y"
     {
 		    ((gse_arg *)arg)->set_gsec(
 		       build_dual_gse_clause((gse_arg *)(arg), (yyvsp[(3) - (5)].id), (yyvsp[(2) - (5)].op), (yyvsp[(1) - (5)].val), (yyvsp[(4) - (5)].op),
@@ -1402,7 +1403,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1406 "gse.tab.c"
+#line 1407 "gse.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1616,7 +1617,7 @@ yyreturn:
 }
 
 
-#line 133 "gse.y"
+#line 134 "gse.y"
 
 
 void
