@@ -23,9 +23,11 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
-#include <stdio.h>		// for create_cache_root_test
-#include <unistd.h>		// ditto
+#include <unistd.h>   // for access stat
+#include <sys/types.h>
+#include <sys/stat.h>
 
+#include <cstdio>     // for create_cache_root_test
 #include <string>
 #include <vector>
 #include <algorithm>
@@ -57,6 +59,9 @@ using namespace std;
 #define W_OK 2
 #endif
 
+namespace libdap
+{
+
 inline static int
 file_size(string name)
 {
@@ -267,6 +272,10 @@ public:
 	hc->create_cache_root("/tmp/silly/");
 	CPPUNIT_ASSERT(access("/tmp/silly/", F_OK) == 0);
 	remove("/tmp/silly");
+#if 0
+	// This test doesn't work on some machines where the build is 
+	// run as root or where /root is owned by some other user (as is
+	// the case with OS/X.
 	try {
 	    hc->create_cache_root("/root/very_silly/");
 	    access("/root/very_silly/", F_OK);
@@ -277,6 +286,7 @@ public:
 	    CPPUNIT_ASSERT("This is where we want to be");
 	    CPPUNIT_ASSERT(access("/root/very_silly/", F_OK) != 0);
 	}
+#endif
     }
 
     void set_cache_root_test() {
@@ -323,7 +333,10 @@ public:
 	CPPUNIT_ASSERT(hc->create_hash_directory(391)
 		       == "/tmp/dods_test_cache/391");
 	CPPUNIT_ASSERT(access("/tmp/dods_test_cache/391", W_OK) == 0);
-
+#if 0
+	// This test doesn't work on some machines where the build is 
+	// run as root or where /root is owned by some other user (as is
+	// the case with OS/X.
 	hc->set_cache_root("/root/");
 	try {
 	    hc->create_hash_directory(391);
@@ -331,7 +344,7 @@ public:
 	}
 	catch (Error &e) {
 	}
-
+#endif
 	remove("/tmp/dods_test_cache/391");
 
     }
@@ -800,6 +813,8 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(HTTPCacheTest);
 
+} // namespace libdap
+
 int 
 main( int, char** )
 {
