@@ -27,6 +27,7 @@
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
 
+#include <cstring>
 #include <iterator>
 #include <string>
 #include <algorithm>
@@ -38,10 +39,14 @@
 #include "HTTPConnect.h"
 #include "RCReader.h"
 #include "debug.h"
+#include <test_config.h>
 
 using namespace CppUnit;
 using namespace std;
 
+namespace libdap
+{
+
 class HTTPConnectTest: public TestFixture {
   private:
     HTTPConnect * http;
@@ -199,7 +204,8 @@ class HTTPConnectTest: public TestFixture {
             delete stuff;
             stuff = 0;
 
-            stuff = http->fetch_url("file://HTTPConnectTest.cc");
+	    string url = (string)"file://test_config.h" ;
+            stuff = http->fetch_url(url);
             CPPUNIT_ASSERT(fread(&c, 1, 1, stuff->get_stream()) == 1
                            && !ferror(stuff->get_stream())
                            && !feof(stuff->get_stream()));
@@ -414,6 +420,8 @@ dods_test." << endl;
 
 CPPUNIT_TEST_SUITE_REGISTRATION(HTTPConnectTest);
 
+}
+
 int main(int, char **)
 {
     CppUnit::TextTestRunner runner;
