@@ -25,8 +25,8 @@
  
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 
+#include <cstring>
 #include <string>
 #include <iostream>
 #include <fstream>
@@ -35,13 +35,17 @@
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
 
-// #define DODS_DEBUG
+#define DODS_DEBUG
 #include "RCReader.h"
 #include "debug.h"
+#include <test_config.h>
 
 using namespace CppUnit;
 using namespace std;
 
+namespace libdap
+{
+
 class RCReaderTest : public TestFixture {
 private:
     RCReader *rcr;
@@ -67,6 +71,8 @@ public:
     CPPUNIT_TEST(proxy_test1);
     CPPUNIT_TEST(proxy_test2);
     CPPUNIT_TEST(proxy_test3);
+    CPPUNIT_TEST(proxy_test4);
+    CPPUNIT_TEST(proxy_test5);
     CPPUNIT_TEST(validate_ssl_test);
     
     CPPUNIT_TEST_SUITE_END();
@@ -168,16 +174,16 @@ public:
 
     // Read the proxy info from rcreader-testsuite/test1.rc
     void proxy_test1() {
-	char rc[] = { "DODS_CONF=rcreader-testsuite/test1.rc" };
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/test1.rc" ;
 	DBG(cerr << "rc: " << rc << endl);
-	putenv(rc);
+	putenv((char *)rc.c_str());
 
 	RCReader::delete_instance();
 	RCReader::initialize_instance();
 	RCReader *reader = RCReader::instance();
 	DBG(cerr << "RC path: " << reader->d_rc_file_path << endl);
 	CPPUNIT_ASSERT(reader->d_rc_file_path 
-		       == "rcreader-testsuite/test1.rc");
+		       == (string)TEST_SRC_DIR + "/rcreader-testsuite/test1.rc");
 	CPPUNIT_ASSERT(reader->get_proxy_server_protocol() == "http");
 
 	string proxy = reader->get_proxy_server_host_url();
@@ -193,16 +199,16 @@ public:
     }
 
     void proxy_test2() {
-	char rc[] = { "DODS_CONF=rcreader-testsuite/test2.rc" };
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/test2.rc" ;
 	DBG(cerr << "rc: " << rc << endl);
-	putenv(rc);
+	putenv((char *)rc.c_str());
 
 	RCReader::delete_instance();
 	RCReader::initialize_instance();
 	RCReader *reader = RCReader::instance();
 	DBG(cerr << "RC path: " << reader->d_rc_file_path << endl);
 	CPPUNIT_ASSERT(reader->d_rc_file_path 
-		       == "rcreader-testsuite/test2.rc");
+		       == (string)TEST_SRC_DIR + "/rcreader-testsuite/test2.rc");
 	CPPUNIT_ASSERT(reader->get_proxy_server_protocol() == "http");
 
 	string proxy = reader->get_proxy_server_host_url();
@@ -215,9 +221,9 @@ public:
     }
 
     void proxy_test3() {
-	char rc[] = { "DODS_CONF=rcreader-testsuite/test3.rc" };
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/test3.rc" ;
 	DBG(cerr << "rc: " << rc << endl);
-	putenv(rc);
+	putenv((char *)rc.c_str());
 
 	try {
 	    RCReader::delete_instance();
@@ -230,11 +236,70 @@ public:
 	}
     }
     
+    void proxy_test4() {
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/test4.rc" ;
+	DBG(cerr << "rc: " << rc << endl);
+	putenv((char *)rc.c_str());
+
+	try {
+	    RCReader::delete_instance();
+	    RCReader::initialize_instance();
+	    RCReader *reader = RCReader::instance();
+	    DBG(cerr << "RC path: " << reader->d_rc_file_path << endl);
+	    CPPUNIT_ASSERT(reader->d_rc_file_path 
+			   == (string)TEST_SRC_DIR + "/rcreader-testsuite/test4.rc");
+	    CPPUNIT_ASSERT(reader->get_proxy_server_protocol() == "http");
+
+	    string proxy = reader->get_proxy_server_host_url();
+	    DBG(cerr << "get_proxy_server_host_url(): " << proxy << endl);
+	    CPPUNIT_ASSERT(proxy == "jimg:test@proxy.local.org:3128");
+
+	    CPPUNIT_ASSERT(reader->get_proxy_server_host() == "proxy.local.org");
+	    CPPUNIT_ASSERT(reader->get_proxy_server_port() == 3128);
+	    CPPUNIT_ASSERT(reader->get_proxy_server_userpw() == "jimg:test");
+	}
+	catch(Error &e) {
+	    DBG(cerr << e.get_error_message() << endl);
+	    CPPUNIT_ASSERT(e.get_error_message() != "");
+	}
+    }
+    
+    void proxy_test5() {
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/test5.rc" ;
+	DBG(cerr << "rc: " << rc << endl);
+	putenv((char *)rc.c_str());
+
+	try {
+	    RCReader::delete_instance();
+	    RCReader::initialize_instance();
+	    RCReader *reader = RCReader::instance();
+	    DBG(cerr << "RC path: " << reader->d_rc_file_path << endl);
+	    CPPUNIT_ASSERT(reader->d_rc_file_path 
+			   == (string)TEST_SRC_DIR + "/rcreader-testsuite/test5.rc");
+	    string proxy = reader->get_proxy_server_host_url();
+	    DBG(cerr << "get_proxy_server_host_url(): " << proxy << endl);
+	    CPPUNIT_ASSERT(reader->get_proxy_server_protocol() == "http");
+
+	    CPPUNIT_ASSERT(proxy == "jimg:test@proxy.local.org:3128");
+
+	    CPPUNIT_ASSERT(reader->get_proxy_server_host() == "proxy.local.org");
+	    CPPUNIT_ASSERT(reader->get_proxy_server_port() == 3128);
+	    CPPUNIT_ASSERT(reader->get_proxy_server_userpw() == "jimg:test");
+	}
+	catch(Error &e) {
+	    DBG(cerr << e.get_error_message() << endl);
+	    CPPUNIT_ASSERT(e.get_error_message() != "");
+	}
+    }
+    
+
     // This simple test checks to see that the VALIDATE_SSL parameter is 
     // read correctly.
     void validate_ssl_test() {
+	string rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/dodssrc_ssl_1" ;
+	DBG(cerr << "rc: " << rc << endl);
+	putenv((char *)rc.c_str());
 
-        putenv("DODS_CONF=rcreader-testsuite/dodsrc_ssl_1");
         RCReader::delete_instance();
         RCReader::initialize_instance();
         RCReader *reader = RCReader::instance();
@@ -244,7 +309,10 @@ public:
         CPPUNIT_ASSERT(reader->get_validate_ssl() == 1);
 
         // Param set in file
-        putenv("DODS_CONF=rcreader-testsuite/dodsrc_ssl_2");
+	rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/dodssrc_ssl_2" ;
+	DBG(cerr << "rc: " << rc << endl);
+	putenv((char *)rc.c_str());
+
         RCReader::delete_instance();
         RCReader::initialize_instance();
         reader = RCReader::instance();
@@ -255,7 +323,10 @@ public:
         CPPUNIT_ASSERT(reader->get_validate_ssl() == 1);
 
         // Param cleared in file 
-        putenv("DODS_CONF=rcreader-testsuite/dodsrc_ssl_3");
+	rc = (string)"DODS_CONF=" + TEST_SRC_DIR + "/rcreader-testsuite/dodsrc_ssl_3" ;
+	DBG(cerr << "rc: " << rc << endl);
+	putenv((char *)rc.c_str());
+
         RCReader::delete_instance();
         RCReader::initialize_instance();
         reader = RCReader::instance();
@@ -267,6 +338,8 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(RCReaderTest);
 
+} // namespace libdap
+
 int 
 main( int, char** )
 {
