@@ -36,12 +36,12 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: util.cc 17506 2007-11-28 21:20:52Z jimg $"
+    {"$Id: util.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
+#include <cassert>
+#include <cstring>
+
 #include <ctype.h>
 #ifndef TM_IN_SYS_TIME
 #include <time.h>
@@ -50,7 +50,7 @@ static char rcsid[] not_used =
 #endif
 
 #ifndef WIN32
-#include <unistd.h>
+#include <unistd.h>    // for stat
 #else
 #include <io.h>
 #include <fcntl.h>
@@ -79,6 +79,8 @@ static char rcsid[] not_used =
 
 using namespace std;
 
+namespace libdap {
+
 // Remove spaces from the start of a URL and from the start of any constraint
 // expression it contains. 4/7/98 jhrg
 
@@ -376,6 +378,15 @@ downcase(string &s)
         s[i] = tolower(s[i]);
 }
 
+string
+remove_quotes(const string &s)
+{
+    if (!s.empty() && s[0] == '\"' && s[s.length()-1] == '\"')
+        return s.substr(1, s.length() - 2);
+    else
+        return s;
+}
+
 #ifdef WIN32
 //  Sometimes need to buffer within an iostream under win32 when
 //  we want the output to go to a FILE *.  This is because
@@ -487,6 +498,7 @@ path_to_filename(string path)
     return (pos == string::npos) ? path : path.substr(++pos);
 }
 
+#if 0
 // Look around for a reasonable place to put a temporary file. Check first
 // the value of the TMPDIR env var. If that does not yeild a path that's
 // writable (as defined by access(..., W_OK|R_OK)) then look at P_tmpdir (as
@@ -510,20 +522,23 @@ get_tempfile_template(char *file_template)
     Regex directory("[-a-zA-Z0-9_\\]*");
 	
     c = getenv("TEMP");
-    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0)
+    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0))
     	goto valid_temp_directory;
 
     c= getenv("TMP");
-    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0)
+    if (c && directory.match(c, strlen(c)) && (access(getenv("TEMP"), 6) == 0))
     	goto valid_temp_directory;
 #else
-	// whitelist for a directory
-	Regex directory("[-a-zA-Z0-9_/]*");
 	
 	c = getenv("TMPDIR");
-	if (c && directory.match(c, strlen(c)) && (access(c, W_OK | R_OK) == 0))
-    	goto valid_temp_directory;
-
+	// Changed this so that it uses the pathname_ok() method instead
+	// of using its own regex. jhrg 2/4/08
+	if (c) {
+	    string tmpdir = *c;
+	    if (pathname_ok(tmpdir) && (access(c, W_OK | R_OK) == 0))
+	        goto valid_temp_directory;
+	}
+	
 #ifdef P_tmpdir
 	if (access(P_tmpdir, W_OK | R_OK) == 0) {
         c = P_tmpdir;
@@ -549,6 +564,7 @@ valid_temp_directory:
 
     return temp;
 }
+#endif
 
 /** Intended for testing, this may have other uses. The template should be
     the pathname of the temporary file ending in 'XXXXXX' (as for mkstemp)
@@ -618,7 +634,7 @@ pathname_ok(const string &path, bool strict)
     if (path.length() > 255)
         return false;
     
-    Regex name("[0-9A-z_./-]+");
+    Regex name("[-0-9A-z_./]+");
     if (!strict)
         name = "[:print:]+";
         
@@ -633,3 +649,6 @@ pathname_ok(const string &path, bool strict)
 }
 
 //@}
+
+} // namespace libdap
+
